==> synhelper-8.x-1.51.tar.gz: synhelper/src/Service/TaxonomyImport.php <==
<?php

namespace Drupal\synhelper\Service;

use Drupal\Core\Config\FileStorage;

/**
 * TaxomyImport class.
 *
 * @internal
 *   For internal usage by the Commerce synhelper module.
 */
class TaxonomyImport implements ContentImportInterface {

  /**
   * Service for service.
   *
   * @var Drupal\synhelper\Service\FilesImport
   */
  protected $filesImport;

  /**
   * Service for service.
   *
   * @var Drupal\synhelper\Service\ParagraphImport
   */
  protected $paragraphImport;

  /**
   * Controller constructor.
   */
  public function __construct(ContentImportInterface $filesImport, ContentImportInterface $paragraphImport) {
    $this->filesImport = $filesImport;
    $this->paragraphImport = $paragraphImport;
  }

  /**
   * Import Taxonomy.
   */
  public function import(string $directory) {
    $sourceTaxonomy = new FileStorage($directory . '/taxonomy');
    foreach ($sourceTaxonomy->listAll() as $file) {
      $data = $sourceTaxonomy->read($file);
      if (!$this->checkVocabularyExistence($data['vid'])) {
        $this->createVocabulary($data);
      }
      $this->createTaxonomyTerm($data);
      if (!empty($data['children_terms'])) {
        $this->createChildTerms($data, $data['vid']);
      }
    }
  }

  /**
   * Import TaxonomyField by name or name and vocabulary.
   */
  public function importTaxonomyField($taxonomyTermName) {
    if (!empty($taxonomyTermName)) {
      $taxonomyTermId = $this->getTidByName($taxonomyTermName);
      return $taxonomyTermId;
    }
  }

  /**
   * Checks vocabulary for existence.
   */
  private function checkVocabularyExistence(string $vid) : bool {
    $vocabulary_storage = \Drupal::entityTypeManager()->getStorage('taxonomy_vocabulary');
    if (empty($vocabulary_storage->load($vid))) {
      return FALSE;
    }
    return TRUE;
  }

  /**
   * Creates taxonomy vocabulary.
   */
  private function createVocabulary(array $data) {
    $vocabulary_storage = \Drupal::entityTypeManager()->getStorage('taxonomy_vocabulary');
    if (!empty($data['vname'])) {
      $vocabulary_name = $data['vname'];
    }
    else {
      $vocabulary_name = $data['vid'];
    }
    $t = [
      'uid' => 1,
      'vid' => $data['vid'],
      'name' => $vocabulary_name,
    ];
    $vocabulary = $vocabulary_storage->create($t);
    $vocabulary->save();
  }

  /**
   * Creates taxonomy term.
   */
  private function createTaxonomyTerm(array $data) {
    $t = [
      'uid' => 1,
      'vid' => $data['vid'],
      'name' => $data['name'],
      'weight' => $data['weight'],
      'field_catalog_image' => $this->filesImport->importImages($data['field_catalog_image']),
    ];
    $storage = \Drupal::entityTypeManager()->getStorage('taxonomy_term');
    $taxonomyTerm = $storage->create($t);
    $taxonomyTerm->save();
  }

  /**
   * Creates all child taxonomy terms.
   */
  private function createChildTerms($data, $vid) {
    $child_terms = [];
    foreach ($data['children_terms'] as $child_term) {
      $t = [
        'uid' => 1,
        'vid' => $vid,
        'name' => $child_term['name'],
        'field_catalog_image' => $this->filesImport->importImages($child_term['field_catalog_image']),
        'weight' => $child_term['weight'],
        'parent' => [
          ['target_id' => $this->getTidByName($data['name'])],
        ],

      ];
      $storage = \Drupal::entityTypeManager()->getStorage('taxonomy_term');
      $term = $storage->create($t);
      $term->save();
      if (!empty($child_term['children_terms'])) {
        $this->createChildTerms($child_term, $vid);
      }
    }
  }

  /**
   * Get taxonomy term id by name or by name and vocabulary id.
   */
  private function getTidByName($name = NULL, $vid = NULL) {
    $properties = [];
    if (!empty($name)) {
      $properties['name'] = $name;
    }
    if (!empty($vid)) {
      $properties['vid'] = $vid;
    }
    $terms = \Drupal::entityTypeManager()->getStorage('taxonomy_term')->loadByProperties($properties);
    $term = reset($terms);
    return !empty($term) ? $term->id() : 0;
  }

}

==> synhelper-8.x-1.54.tar.gz: synhelper/src/Service/TaxonomyImport.php <==
<?php

namespace Drupal\synhelper\Service;

use Drupal\Core\Config\FileStorage;

/**
 * TaxomyImport class.
 *
 * @internal
 *   For internal usage by the Commerce synhelper module.
 */
class TaxonomyImport implements ContentImportInterface {

  /**
   * Service for service.
   *
   * @var Drupal\synhelper\Service\FilesImport
   */
  protected $filesImport;

  /**
   * Controller constructor.
   */
  public function __construct(ContentImportInterface $filesImport) {
    $this->filesImport = $filesImport;
  }

  /**
   * Import Taxonomy.
   */
  public function import(string $directory) {
    $sourceTaxonomy = new FileStorage($directory . '/taxonomy');
    foreach ($sourceTaxonomy->listAll() as $file) {
      $data = $sourceTaxonomy->read($file);
      if (!$this->checkVocabularyExistence($data['vid'])) {
        $this->createVocabulary($data);
      }
      $this->createTaxonomyTerm($data);
      if (!empty($data['children_terms'])) {
        $this->createChildTerms($data, $data['vid']);
      }
    }
  }

  /**
   * Import TaxonomyField by name or name and vocabulary.
   */
  public function importTaxonomyField($taxonomyTermName) {
    if (!empty($taxonomyTermName)) {
      $taxonomyTermId = $this->getTidByName($taxonomyTermName);
      return $taxonomyTermId;
    }
  }

  /**
   * Checks vocabulary for existence.
   */
  private function checkVocabularyExistence(string $vid) : bool {
    $vocabulary_storage = \Drupal::entityTypeManager()->getStorage('taxonomy_vocabulary');
    if (empty($vocabulary_storage->load($vid))) {
      return FALSE;
    }
    return TRUE;
  }

  /**
   * Creates taxonomy vocabulary.
   */
  private function createVocabulary(array $data) {
    $vocabulary_storage = \Drupal::entityTypeManager()->getStorage('taxonomy_vocabulary');
    if (!empty($data['vname'])) {
      $vocabulary_name = $data['vname'];
    }
    else {
      $vocabulary_name = $data['vid'];
    }
    $t = [
      'uid' => 1,
      'vid' => $data['vid'],
      'name' => $vocabulary_name,
    ];
    $vocabulary = $vocabulary_storage->create($t);
    $vocabulary->save();
  }

  /**
   * Creates taxonomy term.
   */
  private function createTaxonomyTerm(array $data) {
    $t = [
      'uid' => 1,
      'vid' => $data['vid'],
      'name' => $data['name'],
      'weight' => $data['weight'],
      'field_catalog_image' => $this->filesImport->importImages($data['field_catalog_image']),
    ];
    $storage = \Drupal::entityTypeManager()->getStorage('taxonomy_term');
    $taxonomyTerm = $storage->create($t);
    $taxonomyTerm->save();
  }

  /**
   * Creates all child taxonomy terms.
   */
  private function createChildTerms($data, $vid) {
    $child_terms = [];
    foreach ($data['children_terms'] as $child_term) {
      $t = [
        'uid' => 1,
        'vid' => $vid,
        'name' => $child_term['name'],
        'field_catalog_image' => $this->filesImport->importImages($child_term['field_catalog_image']),
        'weight' => $child_term['weight'],
        'parent' => [
          ['target_id' => $this->getTidByName($data['name'])],
        ],

      ];
      $storage = \Drupal::entityTypeManager()->getStorage('taxonomy_term');
      $term = $storage->create($t);
      $term->save();
      if (!empty($child_term['children_terms'])) {
        $this->createChildTerms($child_term, $vid);
      }
    }
  }

  /**
   * Get taxonomy term id by name or by name and vocabulary id.
   */
  private function getTidByName($name = NULL, $vid = NULL) {
    $properties = [];
    if (!empty($name)) {
      $properties['name'] = $name;
    }
    if (!empty($vid)) {
      $properties['vid'] = $vid;
    }
    $terms = \Drupal::entityTypeManager()->getStorage('taxonomy_term')->loadByProperties($properties);
    $term = reset($terms);
    return !empty($term) ? $term->id() : 0;
  }

}
